==> win32_Release_v4.0.0_r895.zip: data/scripts/ui/PopupAcademyTroops.lua <==
amta^  VL>[*_6D!){=t|ampq!N>K;x
ozg@ictp$횽U6W3V;BddgGzZ!\n .C
y/N"K/2ty
o[ϝȭ÷엕Ժ?"G0 U;X$;;!	zkkV?E 	
'
*F)H,mugq{r'n:U:V%gi
]4PǡöжӡȭκѽػϪ樨vliI=U0^T]Taec #
ngt?5weߛײ茆޽ss'BỼӳqs]ٶجͤʯLLg¢ڼrTyAAw1,|}}yC$A5vw=DuiAc+N/Ke@%])TELצӳqrwM.F'I.Kcͪϻ鎦ՇƏƁޜɀ̈򠇮숨䀊p{~o\ @/K2NKN/\/F5AdVQvUQy[̯΢ǣVQ{;׵ټxmoעВϹܰ툄&/'(#"?A@qY	繻FڮˤٸѣB??>7S<ۆ(+"w[Ϯç19lkl$A-]8J2/WVR}u]+%aAa\|*A.\	@jҧ-+
TU}27_:_;vtr E6S2@#K.DjSS͸نӯp,@,y|(Gx~sΣ¶{u[ѩ庘Ϲtp\DC
ihV7Y8_<)F'Cp:/#:110@AGjQJW'+%vu6k}
[jU2ia5T6tun s[pl}ޤ|~'&ؼݼϪsq]¯ݴCoOlLMztXxIa]SܿʸxuRZoA-GDol e'_[]|t/Ut]o߾	)(|WƞaV@B#G#wS׵-hI&h9ؠҩ%
beBd`Bk^nwXʤ\\!7>qY	ZORN_
LDUT0;8k~
yQjcojEtsOr^XZ
kx:6)I7ٷpqYűԦϮȠձn)AF慧!cjJK}!+"PrD=0m|>_-}`uc8}xTtWNkEs[^[yUuAq]}Oh㛓3?=~}`@L89Szӑе}RoJ#zq3TɋMFk@FdGww-]bZ[|k`Rrk㞕踽A|ےƖِފfmkY{WwOSsEeQκE[|⥇OrRg=6@@vAay֕ډNZ]nL`@v@lLLk /cji0U9U:M4']K˙DnL;הASDWVg*,ܵT< <?j}n
/ꏇ66>023[{Iz  ..,)`}	hj7Gh^ZX@A60I.ϯOPČ<ݨ24kpm2F)vU%!  iaE=yZ,\.<1/v
(Ԕ̮宯ĸsQ=8P7t,K.Z70)	9%gۨܮϦڃNVt^ (!,z|NfD853_zӡϦȯ7+)
}퉆7<
!#EIcOO
;s80z^Ғ:.߫Â悡8qrs! ] ๾@WR`SeIi^jC647+&'WCWe4ƋZel9ɤͩ͡Də5qvqsTPR`lk*ߓ}zfWחG |iY9>˗Ԕ)񣄱IKii'3ךo^dPTw-BO;nde M=Ij
W^;U!	+~iz{egEJ ˛ZPw$.34*&"ލcaŽ?<}oHTV>/8-}K3<LM1Lc*^}T|sTֻ$T}]3"ozP||-$-[_	\0!6'/ykbkMޓ&$GcDk蜥$^|֢ײƳu#	62HKjmpRr3Om&g	}G5P=R$As_6
|^_"+FM:4O:Tv]z]H3:./Ÿܨ_[7CPz)ҺlAd<4F($MDviFo㏏D߳ڹҷ=b@fGv(.l?/-$gazG5Z*o=3m}tXxze0y=1T(+*6r[{|D!R&I;𺻒ΘWQaO|68#
[ïM*1^=AE`gK	>?E=rs/.- '$m|[K،󤭧͸ʸݳǓ±ʃ씴[SD0pwYHJwUU.%CKzbca" '?])G3xSy*
7BbYLCd:;1"&%V3Gj;{;*ƫCw8<zM(:]Y)|yPnz)3?x7#+1]%.Y~{{i;3B$PfW^Wp`eC*ҝ9
u|Xt6~"ZРrbK+ &&`	e	)ZxD;UĨ1$:GdTP#S6S7=4vv-`a#0"	{tv]@AsF[Zli^BC@4U'@%QէΡӺηwuWMՅ""^o[+*Ťҷ⧦GGsGFoH}Cۍˮݾ%)r_{T0]:FSx`e>е

?INlNg6V:_,D(Ikr0:Ϣű J%W}@@rͅ#
Kvi`iEab3"
;-m+! VzCA|:\4!(!47X&ۨǰؒZy7x_{+	;ȧȼŤȤ.(HIUw}};JH͍Х˿utO/w
 c,:^}Ya%<CӼNhO?wuPȤ!uPcGFBp-wq]Y{Ub{~nK3M?OE92_Fa<|MEQЫ)0L=$2/O|$zO?$	$	.A2ʾD]=	.7>5T^~N%P o
rxZRtaJh{ퟟ:;-``]upNGn6x@)
4賲ܹܸ!afNh`6+CJ^8聣׳b@nU%<[r:1/?>yyWpLl9:89xr
PauRXZrPw#.rr@`riiDp6XkSsz[y<<ͱED遣o"F7ƻ)/'-/iJP5Q0""!m(~;w(z?n;r e!*
q
-(iNbmEn皶ϐXSsBnMEGBJ4`u1oH(2NaQY	J+zǳbw۫t~w0<w-.b[>",33(+~^zP02yQv<)΢zc'R|xRBWS#!>=8,쿘pP{M'Woo%X5T,
¶ԡӃvy[dgzR2bиyy+CmIfA]*&ޣۯwy|foL KC@{tcݴ?*6*19iimCmMoO?0:
bg:u]
7u?kwvX{	&j;3>/syYtYq->46~zb@@~O?[Q	sx !/7<Jr*+  ǈI]tqsS߅+*#LGקb1yrFZ#&K@rPD ˤ쟽ף<i) es#;:^eU6+OKbJDlPbK02'&$)c
	ndG	+ˈ<S=ڤ)xZ8kjWoܽ:?fgVpD`@H9:_1T&A8bcq5Xx|8)褵Y[~=  m|Hp䈙emW t}PzXu(
/}~!q>n;k~OKiGKn9jJvT2~\/%%8pTv.
jR`/(
ֺi{sv\<Jp`MSoHA]Y,B6Y,O'4ѝ":~[[lKA% g3ZIEFG`saM^NKSPv4=4
6swK~S+¯힌ƮTȼЩVeVaI90J{/-@pZ涷뙬 8x4wڹܼ:`h	%quDZTn_HI{
%,ʮ󒂉17״2fI592M(EyQήo~#fOwuP۵üU'D!
ĩxqlR6X9-%P7g~]-MMeGkUXﷴNN&"$632Ձ
܃࿃	b(tRwbkA<5ڄ![P(ޒL! n|0rXxk1İ卄L.67y Y|Wkgv.=ٶu9YȭٹҨ +	Bk$
.`EkaD~Y]ĨWjJ@LO#N7X,!и٪ڨǩں`h)M)@4]2\=QyQ	(ر
	iafp2G4Mcz9ypUy`Rpf@(
:n*9*/ ,RaGoJ:3KM18ٓWUW30ON.'ꆅ˓:G\ "0PK,HKl8:tJ^?/BC#(
N2,=I6D!R.-?޻޺?
xոu]&&e߫Ңƈ
еԧȦ75:UF>w<6V;SR`v}]`pbGN3ױ-/LnJ*#/$Mڎ΀M1P4PxHj˪{ʾֿPFdoD`t,g,	%]uXǷ홃gSqQeJ`@Ŀ֥yi{gw[{Ptdl5kLn |Sp-kvٶؾץ%S#WbXbEDdo0.=qC籑wݻ;#?zOjo`S3"X'Z|@-	;pT|B`ܜq^O?ϣ˳gs6.=R*[FdXscl MYh'2ֶz?3$}_MεqM5Z"vgfT
 ȭ+YM{	,L&kKvXװաߞcw_AJoʍ߬{\êS°9ЧBo!IdIjXhKhF>	+27g;9$ Puw*M(\Ňȓ?>)m/`V㏻׹ɼȗ⌨'30CCskjB&lO'PT1CoP>441Rz~KcO>cxS\o|%8Cs_NbBp


==> win32_Release_v4.0.1_r916.zip: data/scripts/ui/PopupAcademyTroops.lua <==
amta^  VL>[*_6D!){=t|ampq!N>K;x
ozg@ictp$횽U6W3V;BddgGzZ!\n .C
y/N"K/2ty
o[ϝȭ÷엕Ժ?"G0 U;X$;;!	zkkV?E 	
'
*F)H,mugq{r'n:U:V%gi
]4PǡöжӡȭκѽػϪ樨vliI=U0^T]Taec #
ngt?5weߛײ茆޽ss'BỼӳqs]ٶجͤʯLLg¢ڼrTyAAw1,|}}yC$A5vw=DuiAc+N/Ke@%])TELצӳqrwM.F'I.Kcͪϻ鎦ՇƏƁޜɀ̈򠇮숨䀊p{~o\ @/K2NKN/\/F5AdVQvUQy[̯΢ǣVQ{;׵ټxmoעВϹܰ툄&/'(#"?A@qY	繻FڮˤٸѣB??>7S<ۆ(+"w[Ϯç19lkl$A-]8J2/WVR}u]+%aAa\|*A.\	@jҧ-+
TU}27_:_;vtr E6S2@#K.DjSS͸نӯp,@,y|(Gx~sΣ¶{u[ѩ庘Ϲtp\DC
ihV7Y8_<)F'Cp:/#:110@AGjQJW'+%vu6k}
[jU2ia5T6tun s[pl}ޤ|~'&ؼݼϪsq]¯ݴCoOlLMztXxIa]SܿʸxuRZoA-GDol e'_[]|t/Ut]o߾	)(|WƞaV@B#G#wS׵-hI&h9ؠҩ%
beBd`Bk^nwXʤ\\!7>qY	ZORN_
LDUT0;8k~
yQjcojEtsOr^XZ
kx:6)I7ٷpqYűԦϮȠձn)AF慧!cjJK}!+"PrD=0m|>_-}`uc8}xTtWNkEs[^[yUuAq]}Oh㛓3?=~}`@L89Szӑе}RoJ#zq3TɋMFk@FdGww-]bZ[|k`Rrk㞕踽A|ےƖِފfmkY{WwOSsEeQκE[|⥇OrRg=6@@vAay֕ډNZ]nL`@v@lLLk /cji0U9U:M4']K˙DnL;הASDWVg*,ܵT< <?j}n
/ꏇ66>023[{Iz  ..,)`}	hj7Gh^ZX@A60I.ϯOPČ<ݨ24kpm2F)vU%!  iaE=yZ,\.<1/v
(Ԕ̮宯ĸsQ=8P7t,K.Z70)	9%gۨܮϦڃNVt^ (!,z|NfD853_zӡϦȯ7+)
}퉆7<
!#EIcOO
;s80z^Ғ:.߫Â悡8qrs! ] ๾@WR`SeIi^jC647+&'WCWe4ƋZel9ɤͩ͡Də5qvqsTPR`lk*ߓ}zfWחG |iY9>˗Ԕ)񣄱IKii'3ךo^dPTw-BO;nde M=Ij
W^;U!	+~iz{egEJ ˛ZPw$.34*&"ލcaŽ?<}oHTV>/8-}K3<LM1Lc*^}T|sTֻ$T}]3"ozP||-$-[_	\0!6'/ykbkMޓ&$GcDk蜥$^|֢ײƳu#	62HKjmpRr3Om&g	}G5P=R$As_6
|^_"+FM:4O:Tv]z]H3:./Ÿܨ_[7CPz)ҺlAd<4F($MDviFo㏏D߳ڹҷ=b@fGv(.l?/-$gazG5Z*o=3m}tXxze0y=1T(+*6r[{|D!R&I;𺻒ΘWQaO|68#
[ïM*1^=AE`gK	>?E=rs/.- '$m|[K،󤭧͸ʸݳǓ±ʃ씴[SD0pwYHJwUU.%CKzbca" '?])G3xSy*
7BbYLCd:;1"&%V3Gj;{;*ƫCw8<zM(:]Y)|yPnz)3?x7#+1]%.Y~{{i;3B$PfW^Wp`eC*ҝ9
u|Xt6~"ZРrbK+ &&`	e	)ZxD;UĨ1$:GdTP#S6S7=4vv-`a#0"	{tv]@AsF[Zli^BC@4U'@%QէΡӺηwuWMՅ""^o[+*Ťҷ⧦GGsGFoH}Cۍˮݾ%)r_{T0]:FSx`e>е

?INlNg6V:_,D(Ikr0:Ϣű J%W}@@rͅ#
Kvi`iEab3"
;-m+! VzCA|:\4!(!47X&ۨǰؒZy7x_{+	;ȧȼŤȤ.(HIUw}};JH͍Х˿utO/w
 c,:^}Ya%<CӼNhO?wuPȤ!uPcGFBp-wq]Y{Ub{~nK3M?OE92_Fa<|MEQЫ)0L=$2/O|$zO?$	$	.A2ʾD]=	.7>5T^~N%P o
rxZRtaJh{ퟟ:;-``]upNGn6x@)
4賲ܹܸ!afNh`6+CJ^8聣׳b@nU%<[r:1/?>yyWpLl9:89xr
PauRXZrPw#.rr@`riiDp6XkSsz[y<<ͱED遣o"F7ƻ)/'-/iJP5Q0""!m(~;w(z?n;r e!*
q
-(iNbmEn皶ϐXSsBnMEGBJ4`u1oH(2NaQY	J+zǳbw۫t~w0<w-.b[>",33(+~^zP02yQv<)΢zc'R|xRBWS#!>=8,쿘pP{M'Woo%X5T,
¶ԡӃvy[dgzR2bиyy+CmIfA]*&ޣۯwy|foL KC@{tcݴ?*6*19iimCmMoO?0:
bg:u]
7u?kwvX{	&j;3>/syYtYq->46~zb@@~O?[Q	sx !/7<Jr*+  ǈI]tqsS߅+*#LGקb1yrFZ#&K@rPD ˤ쟽ף<
g'/7ʦ,[Ëy'DED)H0`@T퍤4؀uj
#_Qy0>KM}|UEDdyI% z~]gEq5n˭񏥅v'Mp:膯vTt\h5kԺ߭ʳB@bzl}`kiR.?$iIDPAckN6 )`Q#$hπЅEAcMАlG9%+$:$.x ~A{/0tY5~Lp3EoBp111^CG2\(G2Q9+zv_3wR1&6;~
/ǢOraP$E7%M=95]o~dl"W:yruxT(cH<P)upV-gۏ,&NO
?BCDkvzzmX̌7VAkJ5v08#QTsywvG`DVva01?[Dfҳ!Gz6Qx)Ҿ*`VGi4,3̢i1DWV>:O=4T)Us@R6ʓ{~ȼkkCaMs~ɑhh $$7@PwI%hI3ᩨ'FNnfrWwL~*
'?DO7W!ŋ*
~d,6{	u&5WON{e
)kbk{z栅թbҪ9AϫϠ׹1]&ND!#Pxznl/Q+'OEbb43љ"}wR4v7[7$dZzp|1-dv0B'Btuf፥l𞶑·ef	l](["`tVKmtFd& hMz.jyiE'.gSx_|3M~XpU% ,TR.'
*ap~|Gs彼tw9<AZ&$6MEUWⶴp]MjONcwsʪgAyJh(
2qg
ڿ^kZieG|T//lv֢۫_պVPGO|.K*Y6X-'	/?=>;ܳl%ͱndϩi 2JJ$/2"0AH5ѷ+)Jhl4;JJiϠԽ۲քȬꏎ>!h6nŭ7H0:8Ie=Ԭ|y6FPhrQBv  gM9ѺƯ ·	
yUuUEXS.	-40lC`={fɦȮǵ5C3$,ūW_,-'.'sA??W!MAKMm[xJ߫+9iyR_3`@o
觗Oo^>
_?ew\8x]`CSvTF
~.V(0#7x_gf$g*>A]y%eMu'c/Zx˭AgWFFF;̘鉈~bG&Ca;ɻ*@
->ֳ9'ZyTx?>m[Iq3!"G7dy~\V?2ssQe99(;6Ny[BcGp\ɬbAzXL5[w8[I׻ָ0[]Sۃ欏 <8]/bs<RXXėo]>'Ϗbѹܮܽ
